==> ejc-jlincome-impl-3.0.0-20241009.083421-255-sources.jar: com/ejianc/business/jlincome/bid/bean/EngineeringReportRecordEntity.java <==
package com.ejianc.business.jlincome.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jlincome.bid.bean.EngineeringRecordPersonEntity;
import com.ejianc.business.jlincome.bid.bean.EngineeringRecordResearchEntity;

/**
 * 投标管理-工程调研报告-记录
 *
 * @author generator
 */
@TableName("ejc_bid_engineering_report_record")
public class EngineeringReportRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_state")
    private Integer billState; // 单据状态
    @TableField(value = "bill_code")
    private String billCode; // 单据编码
    @TableField(value = "engineering_id")
    private Long engineeringId; // 工程主键
    @TableField(value = "engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value = "engineering_code")
    private String engineeringCode; // 工程编码
    @TableField(value = "custom_name")
    private String customName; // 客户名称
    @TableField(value = "org_id")
    private Long orgId; // 组织/区域主键
    @TableField(value = "org_name")
    private String orgName; // 组织名称/区域名称
    @TableField(value = "org_code")
    private String orgCode; // 组织编码/区域编码
    @TableField(value = "project_type_id")
    private Long projectTypeId; // 项目类型
    @TableField(value = "project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value = "product_type")
    private String productType; // 产品类型
    @TableField(value = "product_type_name")
    private String productTypeName; // 产品类型名称
    @TableField(value = "owner_company")
    private String ownerCompany; // 业主单位
    @TableField(value = "design_company")
    private String designCompany; // 设计单位
    @TableField(value = "is_assist")
    private Integer isAssist; // 是否需要协助（1 需要，0）
    @TableField(value = "expected_date")
    private Date expectedDate; // 期望出图时间
    @TableField(value = "estimated_date")
    private Date estimatedDate; // 预计交货时间
    @TableField(value = "estimated_contract_mny")
    private BigDecimal estimatedContractMny; // 预计合同金额
    @TableField(value = "sale_leader_id")
    private Long saleLeaderId; // 销售负责人
    @TableField(value = "sale_leader_name")
    private String saleLeaderName; // 销售负责人名称
    @TableField(value = "sale_leader_phone")
    private String saleLeaderPhone; // 销售负责人联系电话
    @TableField(value = "employee_id")
    private Long employeeId; // 经办人
    @TableField(value = "employee_name")
    private String employeeName; // 经办人名称
    @TableField(value = "dept_id")
    private Long deptId; // 经办部门
    @TableField(value = "dept_name")
    private String deptName; // 经办部门名称
    @TableField(value = "memo")
    private String memo; // 备注
    @TableField(value = "is_repeat")
    private Boolean isRepeat; // 是否重复询价
    @TableField(value = "change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value = "change_id")
    private Long changeId; // 变更主键
    @TableField(value = "change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value = "change_date")
    private Date changeDate; // 变更日期
    @TableField(value = "change_memo")
    private String changeMemo; // 变更原因
    @TableField(value = "effect_date")
    private Date effectDate; // 生效时间
    @TableField(value = "change_employee_id")
    private Long changeEmployeeId; // 变更经办人
    @TableField(value = "change_employee_name")
    private String changeEmployeeName; // 变更经办人名称
    @TableField(value = "report_id")
    private Long reportId; // 原询价主键


    @TableField(exist = false)
    @SubEntity(serviceName = "engineeringRecordPersonService", pidName = "reportId")
    private List<EngineeringRecordPersonEntity> engineeringPersonList = new ArrayList<>(); // 投标管理-工程调研报告-项目主要负责人-记录
    @TableField(exist = false)
    @SubEntity(serviceName = "engineeringRecordResearchService", pidName = "reportId")
    private List<EngineeringRecordResearchEntity> engineeringResearchList = new ArrayList<>(); // 投标管理-工程调研报告-调研报告内容-记录


    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getEngineeringId() {
        return engineeringId;
    }

    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }

    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }

    public String getEngineeringCode() {
        return engineeringCode;
    }

    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }

    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }

    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }

    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }

    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }

    public String getOwnerCompany() {
        return ownerCompany;
    }

    public void setOwnerCompany(String ownerCompany) {
        this.ownerCompany = ownerCompany;
    }

    public String getDesignCompany() {
        return designCompany;
    }

    public void setDesignCompany(String designCompany) {
        this.designCompany = designCompany;
    }

    public Integer getIsAssist() {
        return isAssist;
    }

    public void setIsAssist(Integer isAssist) {
        this.isAssist = isAssist;
    }

    public Date getExpectedDate() {
        return expectedDate;
    }

    public void setExpectedDate(Date expectedDate) {
        this.expectedDate = expectedDate;
    }

    public Date getEstimatedDate() {
        return estimatedDate;
    }

    public void setEstimatedDate(Date estimatedDate) {
        this.estimatedDate = estimatedDate;
    }

    public BigDecimal getEstimatedContractMny() {
        return estimatedContractMny;
    }

    public void setEstimatedContractMny(BigDecimal estimatedContractMny) {
        this.estimatedContractMny = estimatedContractMny;
    }

    public Long getSaleLeaderId() {
        return saleLeaderId;
    }

    public void setSaleLeaderId(Long saleLeaderId) {
        this.saleLeaderId = saleLeaderId;
    }

    public String getSaleLeaderName() {
        return saleLeaderName;
    }

    public void setSaleLeaderName(String saleLeaderName) {
        this.saleLeaderName = saleLeaderName;
    }

    public String getSaleLeaderPhone() {
        return saleLeaderPhone;
    }

    public void setSaleLeaderPhone(String saleLeaderPhone) {
        this.saleLeaderPhone = saleLeaderPhone;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Boolean getIsRepeat() {
        return isRepeat;
    }

    public void setIsRepeat(Boolean isRepeat) {
        this.isRepeat = isRepeat;
    }

    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }

    public Date getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }

    public String getChangeMemo() {
        return changeMemo;
    }

    public void setChangeMemo(String changeMemo) {
        this.changeMemo = changeMemo;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    public Long getChangeEmployeeId() {
        return changeEmployeeId;
    }

    public void setChangeEmployeeId(Long changeEmployeeId) {
        this.changeEmployeeId = changeEmployeeId;
    }

    public String getChangeEmployeeName() {
        return changeEmployeeName;
    }

    public void setChangeEmployeeName(String changeEmployeeName) {
        this.changeEmployeeName = changeEmployeeName;
    }

    public Long getReportId() {
        return reportId;
    }

    public void setReportId(Long reportId) {
        this.reportId = reportId;
    }

    public List<EngineeringRecordPersonEntity> getEngineeringPersonList() {
        return engineeringPersonList;
    }

    public void setEngineeringPersonList(List<EngineeringRecordPersonEntity> engineeringPersonList) {
        this.engineeringPersonList = engineeringPersonList;
    }

    public List<EngineeringRecordResearchEntity> getEngineeringResearchList() {
        return engineeringResearchList;
    }

    public void setEngineeringResearchList(List<EngineeringRecordResearchEntity> engineeringResearchList) {
        this.engineeringResearchList = engineeringResearchList;
    }
}

==> ejc-jlincome-impl-3.0.0-20241028.102610-286-sources.jar: com/ejianc/business/jlincome/bid/bean/EngineeringReportRecordEntity.java <==
package com.ejianc.business.jlincome.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jlincome.bid.bean.EngineeringRecordPersonEntity;
import com.ejianc.business.jlincome.bid.bean.EngineeringRecordResearchEntity;

/**
 * 投标管理-工程调研报告-记录
 *
 * @author generator
 */
@TableName("ejc_bid_engineering_report_record")
public class EngineeringReportRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_state")
    private Integer billState; // 单据状态
    @TableField(value = "bill_code")
    private String billCode; // 单据编码
    @TableField(value = "engineering_id")
    private Long engineeringId; // 工程主键
    @TableField(value = "engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value = "engineering_code")
    private String engineeringCode; // 工程编码
    @TableField(value = "custom_name")
    private String customName; // 客户名称
    @TableField(value = "org_id")
    private Long orgId; // 组织/区域主键
    @TableField(value = "org_name")
    private String orgName; // 组织名称/区域名称
    @TableField(value = "org_code")
    private String orgCode; // 组织编码/区域编码
    @TableField(value = "project_type_id")
    private Long projectTypeId; // 项目类型
    @TableField(value = "project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value = "product_type")
    private String productType; // 产品类型
    @TableField(value = "product_type_name")
    private String productTypeName; // 产品类型名称
    @TableField(value = "owner_company")
    private String ownerCompany; // 业主单位
    @TableField(value = "design_company")
    private String designCompany; // 设计单位
    @TableField(value = "is_assist")
    private Integer isAssist; // 是否需要协助（1 需要，0）
    @TableField(value = "expected_date")
    private Date expectedDate; // 期望出图时间
    @TableField(value = "estimated_date")
    private Date estimatedDate; // 预计交货时间
    @TableField(value = "estimated_contract_mny")
    private BigDecimal estimatedContractMny; // 预计合同金额
    @TableField(value = "sale_leader_id")
    private Long saleLeaderId; // 销售负责人
    @TableField(value = "sale_leader_name")
    private String saleLeaderName; // 销售负责人名称
    @TableField(value = "sale_leader_phone")
    private String saleLeaderPhone; // 销售负责人联系电话
    @TableField(value = "employee_id")
    private Long employeeId; // 经办人
    @TableField(value = "employee_name")
    private String employeeName; // 经办人名称
    @TableField(value = "dept_id")
    private Long deptId; // 经办部门
    @TableField(value = "dept_name")
    private String deptName; // 经办部门名称
    @TableField(value = "memo")
    private String memo; // 备注
    @TableField(value = "is_repeat")
    private Boolean isRepeat; // 是否重复询价
    @TableField(value = "change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value = "change_id")
    private Long changeId; // 变更主键
    @TableField(value = "change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value = "change_date")
    private Date changeDate; // 变更日期
    @TableField(value = "change_memo")
    private String changeMemo; // 变更原因
    @TableField(value = "effect_date")
    private Date effectDate; // 生效时间
    @TableField(value = "change_employee_id")
    private Long changeEmployeeId; // 变更经办人
    @TableField(value = "change_employee_name")
    private String changeEmployeeName; // 变更经办人名称
    @TableField(value = "report_id")
    private Long reportId; // 原询价主键
    private Long installLeaderId; // 安装负责人
    private String installLeaderName; // 安装负责人名称


    @TableField(exist = false)
    @SubEntity(serviceName = "engineeringRecordPersonService", pidName = "reportId")
    private List<EngineeringRecordPersonEntity> engineeringPersonList = new ArrayList<>(); // 投标管理-工程调研报告-项目主要负责人-记录
    @TableField(exist = false)
    @SubEntity(serviceName = "engineeringRecordResearchService", pidName = "reportId")
    private List<EngineeringRecordResearchEntity> engineeringResearchList = new ArrayList<>(); // 投标管理-工程调研报告-调研报告内容-记录


    public Long getInstallLeaderId() {
        return installLeaderId;
    }


    public void setInstallLeaderId(Long installLeaderId) {
        this.installLeaderId = installLeaderId;
    }

    public String getInstallLeaderName() {
        return installLeaderName;
    }

    public void setInstallLeaderName(String installLeaderName) {
        this.installLeaderName = installLeaderName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getEngineeringId() {
        return engineeringId;
    }

    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }

    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }

    public String getEngineeringCode() {
        return engineeringCode;
    }

    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }

    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }

    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }

    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }

    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }

    public String getOwnerCompany() {
        return ownerCompany;
    }

    public void setOwnerCompany(String ownerCompany) {
        this.ownerCompany = ownerCompany;
    }

    public String getDesignCompany() {
        return designCompany;
    }

    public void setDesignCompany(String designCompany) {
        this.designCompany = designCompany;
    }

    public Integer getIsAssist() {
        return isAssist;
    }

    public void setIsAssist(Integer isAssist) {
        this.isAssist = isAssist;
    }

    public Date getExpectedDate() {
        return expectedDate;
    }

    public void setExpectedDate(Date expectedDate) {
        this.expectedDate = expectedDate;
    }

    public Date getEstimatedDate() {
        return estimatedDate;
    }

    public void setEstimatedDate(Date estimatedDate) {
        this.estimatedDate = estimatedDate;
    }

    public BigDecimal getEstimatedContractMny() {
        return estimatedContractMny;
    }

    public void setEstimatedContractMny(BigDecimal estimatedContractMny) {
        this.estimatedContractMny = estimatedContractMny;
    }

    public Long getSaleLeaderId() {
        return saleLeaderId;
    }

    public void setSaleLeaderId(Long saleLeaderId) {
        this.saleLeaderId = saleLeaderId;
    }

    public String getSaleLeaderName() {
        return saleLeaderName;
    }

    public void setSaleLeaderName(String saleLeaderName) {
        this.saleLeaderName = saleLeaderName;
    }

    public String getSaleLeaderPhone() {
        return saleLeaderPhone;
    }

    public void setSaleLeaderPhone(String saleLeaderPhone) {
        this.saleLeaderPhone = saleLeaderPhone;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Boolean getIsRepeat() {
        return isRepeat;
    }

    public void setIsRepeat(Boolean isRepeat) {
        this.isRepeat = isRepeat;
    }

    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }

    public Date getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }

    public String getChangeMemo() {
        return changeMemo;
    }

    public void setChangeMemo(String changeMemo) {
        this.changeMemo = changeMemo;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    public Long getChangeEmployeeId() {
        return changeEmployeeId;
    }

    public void setChangeEmployeeId(Long changeEmployeeId) {
        this.changeEmployeeId = changeEmployeeId;
    }

    public String getChangeEmployeeName() {
        return changeEmployeeName;
    }

    public void setChangeEmployeeName(String changeEmployeeName) {
        this.changeEmployeeName = changeEmployeeName;
    }

    public Long getReportId() {
        return reportId;
    }

    public void setReportId(Long reportId) {
        this.reportId = reportId;
    }

    public List<EngineeringRecordPersonEntity> getEngineeringPersonList() {
        return engineeringPersonList;
    }

    public void setEngineeringPersonList(List<EngineeringRecordPersonEntity> engineeringPersonList) {
        this.engineeringPersonList = engineeringPersonList;
    }

    public List<EngineeringRecordResearchEntity> getEngineeringResearchList() {
        return engineeringResearchList;
    }

    public void setEngineeringResearchList(List<EngineeringRecordResearchEntity> engineeringResearchList) {
        this.engineeringResearchList = engineeringResearchList;
    }
}
